Table of contents
-----------------

* Introduction
* Features
* Schema.org types
* References


Introduction
------------

The **Schema.org Blueprints Starter Kit: Organization** module provides
a starting point for building out an Organization's content and information
model using Schema.org.

The starter kit includes the 
[Organization](https://schema/Organization) and 
[LocalBusiness](https://schema/LocalBusiness) types to distinguish between an 
[Organization](https://schema/Organization) being a conceptual entity and a
[LocalBusiness](https://schema/LocalBusiness) being a physical entity with 
a physical [Place](https://schema.org/Place). Site builders should use 
sub-typing to add additional specificity to
[Organization](https://schema/Organization) and
[LocalBusiness](https://schema/LocalBusiness) types. 

This starter kit leverages [inverseOf](https://schema.org/inverseOf)
relationships for [member](https://schema.org/member),
[employee](https://schema.org/employee),
[subOrganization](https://schema.org/subOrganization),
and [department](https://schema.org/department) to arrange an organization's
hierarchy and defines individual roles within an organization using the
[Role](https://schema.org/Role).

When an Organization and LocalBusiness needs dedicated access controls, 
authoring, or presentation, site builders should create a dedicated 
content type and use the 
[Convert Bundles](https://www.drupal.org/project/convert_bundles) module to 
switch an existing Organization content type to be a more specific sub-type.


Features
--------

- Provides default inverseOf relationships for entity references between 
  Organization, LocalBusiness, and Person content types.
- Defines the entity reference target bundles for Organization, LocalBusiness, 
  and Person relationships.
- Creates an Organization (and Local Business) view at /organization with a shortcut.
- Creates Entity View Attachments (EVA) for Organizations and Local Businesses
  to manage and add sub-organizations, departments, members, and employees.


Schema.org types
----------------

Below are the Schema.org types created by this starter kit.

**Person** (node:Person)  
A person (alive, dead, undead, or fictional).  
<https://schema.org/Person>

```mermaid
flowchart TB

Person((Person))
click Person "https://schema.org/Person"
style Person fill:#ffaacc,stroke:#333,stroke-width:4px;

Organization[Organization]
click Organization "https://schema.org/Organization"

LocalBusiness[LocalBusiness]
click LocalBusiness "https://schema.org/LocalBusiness"

Person --> |"memberOf (Role)"| Organization
Organization --> |"member (Role)"| Person
Person --> |"worksFor (Role)"| LocalBusiness
LocalBusiness --> |"employee (Role)"| Person
```

**Organization** (node:Organization)  
An organization such as a school, NGO, corporation, club, etc.  
<https://schema.org/Organization>

```mermaid
flowchart TB

Person[Person]
click Person "https://schema.org/Person"

Organization((Organization))
click Organization "https://schema.org/Organization"
style Organization fill:#ffaacc,stroke:#333,stroke-width:4px;

OrganizationChild[Organization]
click OrganizationChild "https://schema.org/Organization"

LocalBusiness[LocalBusiness]
click LocalBusiness "https://schema.org/LocalBusiness"

Organization ---> |subOrganization| OrganizationChild
OrganizationChild ---> |parentOrganization| Organization
Organization ---> |subOrganization| LocalBusiness
LocalBusiness ---> |parentOrganization| Organization
Person --> |memberOf| Organization
Organization --> |member| Person
```

**Local Business** (node:LocalBusiness)  
A particular physical business or branch of an organization.  
<https://schema.org/LocalBusiness>

```mermaid
flowchart TB

Organization[Organization]
click Organization "https://schema.org/Organization"

LocalBusiness((LocalBusiness))
click LocalBusiness "https://schema.org/LocalBusiness"
style LocalBusiness fill:#ffaacc,stroke:#333,stroke-width:4px;

LocalBusinessChild[LocalBusiness]
click LocalBusinessChild "https://schema.org/LocalBusiness"

Person[Person]
click Person "https://schema.org/Person"

Organization ---> |subOrganization| LocalBusiness
LocalBusiness ---> |parentOrganization| Organization

LocalBusiness ---> |department| LocalBusinessChild
LocalBusinessChild ---> |parentOrganization| LocalBusiness

Person --> |worksFor| LocalBusiness
LocalBusiness --> |employee| Person
```


References
----------

- @see /admin/reports/schemadotorg/docs/references#Organization
